#!/usr/bin/env python
# -*- coding:utf-8 -*-

"""
    This is a dummy module, to test publishing on pypi.
"""

__version__ = "0.0.2"  # update it in setup.py also. Now!

from core import say_hi

